@@ -13,7 +13,7 @@ var searchData=
   ['samples_10',['samples',['../namespacegl.html#a86d4caaead9cc2b5ad0ad5e23ae0568d',1,'gl']]],
   ['sandybrown_11',['sandybrown',['../namespaceColours.html#aca7d5a81d72547917b11b3476a201653',1,'Colours']]],
   ['scalar_12',['scalar',['../classQuaternion.html#adfe519277223a4cb9321dc7f0d3b5cca',1,'Quaternion']]],
-  ['scale_13',['scale',['../structDisplays_1_1Display.html#a611a3fe584fa04e86538866af0e5d788',1,'Displays::Display::scale()'],['../namespacegl.html#a4f27436ebaceab481939dc1f71b047dc',1,'gl::scale()']]],
+  ['scale_13',['scale',['../namespacegl.html#a4f27436ebaceab481939dc1f71b047dc',1,'gl::scale()'],['../structDisplays_1_1Display.html#a611a3fe584fa04e86538866af0e5d788',1,'Displays::Display::scale()']]],
   ['scalefactor_14',['scaleFactor',['../namespacegl.html#a089af03aaf065f0071f68976412d5fcc',1,'gl']]],
   ['scalefactorlisteners_15',['scaleFactorListeners',['../classComponentPeer.html#a3c815b759167f87c6c9aead83b737b3f',1,'ComponentPeer']]],
   ['scopeuid_16',['scopeUID',['../structExpression_1_1Symbol.html#aaddddb4fd2bad7fcce78adce69ba91d8',1,'Expression::Symbol']]],
@@ -48,7 +48,7 @@ var searchData=
   ['simdnumelements_45',['SIMDNumElements',['../structdsp_1_1SIMDRegister.html#a3a9f728b56ef1b9fd3fceddb51259918',1,'dsp::SIMDRegister']]],
   ['simdregistersize_46',['SIMDRegisterSize',['../structdsp_1_1SIMDRegister.html#a295428a84f540c2442e2c476abc49800',1,'dsp::SIMDRegister']]],
   ['sink_47',['sink',['../namespacegl.html#adf64419877a3a14f2ce4793a8d4e919d',1,'gl']]],
-  ['size_48',['size',['../namespacegl.html#a441d79156826d7dfbf89100bb934a38d',1,'gl']]],
+  ['size_48',['size',['../classImage_1_1BitmapData.html#a60d26c041c2e0269be4ae728a527ea75',1,'Image::BitmapData::size()'],['../namespacegl.html#a441d79156826d7dfbf89100bb934a38d',1,'gl::size()']]],
   ['size4d_49',['size4d',['../namespacegl.html#a99ec9e69e3ca31393906e681e379b02d',1,'gl']]],
   ['sizes_50',['sizes',['../namespacegl.html#a53714ae87440f8b11d33209e7093ace3',1,'gl']]],
   ['skew_51',['skew',['../classNormalisableRange.html#a740639acf2157636fce16138a51bbfa3',1,'NormalisableRange']]],
@@ -92,7 +92,7 @@ var searchData=
   ['srcz_89',['srcZ',['../namespacegl.html#aad49d6c3912cc5dc18bc65061d054595',1,'gl']]],
   ['srxy_90',['srxY',['../namespacegl.html#a0a3051294b1d405cc3ae77a91225386c',1,'gl']]],
   ['stages_91',['stages',['../namespacegl.html#a506f6ab080db784dad27cb9d573a05ec',1,'gl']]],
-  ['start_92',['start',['../structTextDiff_1_1Change.html#ac72e9e25d35530fac7837a2d22c31958',1,'TextDiff::Change::start()'],['../namespacegl.html#adad3a3824fbe72fb0b01074bb01ebe75',1,'gl::start()'],['../classNormalisableRange.html#adc186176e94c6f80eb2c626384054fe3',1,'NormalisableRange::start()'],['../structGridItem_1_1StartAndEndProperty.html#a1f4e27e7a91ec09563b7655a3b4f5ccf',1,'GridItem::StartAndEndProperty::start()']]],
+  ['start_92',['start',['../structGridItem_1_1StartAndEndProperty.html#a1f4e27e7a91ec09563b7655a3b4f5ccf',1,'GridItem::StartAndEndProperty::start()'],['../classNormalisableRange.html#adc186176e94c6f80eb2c626384054fe3',1,'NormalisableRange::start()'],['../structTextDiff_1_1Change.html#ac72e9e25d35530fac7837a2d22c31958',1,'TextDiff::Change::start()'],['../namespacegl.html#adad3a3824fbe72fb0b01074bb01ebe75',1,'gl::start()']]],
   ['startangleradians_93',['startAngleRadians',['../structSlider_1_1RotaryParameters.html#a1b4090a3f77b0183b1c847525f4edb8a',1,'Slider::RotaryParameters']]],
   ['startindex1_94',['startIndex1',['../classAbstractFifo_1_1ScopedReadWrite.html#a102cfbf1cfd342be976af1e97b9ade27',1,'AbstractFifo::ScopedReadWrite']]],
   ['startindex2_95',['startIndex2',['../classAbstractFifo_1_1ScopedReadWrite.html#a742bae60eed284787472c86809f3b179',1,'AbstractFifo::ScopedReadWrite']]],
@@ -100,7 +100,7 @@ var searchData=
   ['startsample_97',['startSample',['../structAudioSourceChannelInfo.html#a42e88ccc05d4893015e2415785390259',1,'AudioSourceChannelInfo']]],
   ['startsegment_98',['startSegment',['../namespacegl.html#af89e8b4413c870557c97cf9c8a3fe1e9',1,'gl']]],
   ['starttime_99',['startTime',['../structUnitTestRunner_1_1TestResult.html#a4a9729ea0d39217a16dd619db024a398',1,'UnitTestRunner::TestResult']]],
-  ['state_100',['state',['../classComponentBuilder.html#af09fdfb8bb0edf0a6c2f19d5d54563f4',1,'ComponentBuilder::state()'],['../classAudioProcessorValueTreeState.html#ad7de02052d045956f56018e009dc50c6',1,'AudioProcessorValueTreeState::state()'],['../structdsp_1_1ProcessorDuplicator.html#a5907f78806648c78d794e1f16943df9d',1,'dsp::ProcessorDuplicator::state()']]],
+  ['state_100',['state',['../classAudioProcessorValueTreeState.html#ad7de02052d045956f56018e009dc50c6',1,'AudioProcessorValueTreeState::state()'],['../structdsp_1_1ProcessorDuplicator.html#a5907f78806648c78d794e1f16943df9d',1,'dsp::ProcessorDuplicator::state()'],['../classComponentBuilder.html#af09fdfb8bb0edf0a6c2f19d5d54563f4',1,'ComponentBuilder::state()']]],
   ['statefilechooser_101',['stateFileChooser',['../classStandalonePluginHolder.html#a5f6cf68a9218c9f93837bc13b7841393',1,'StandalonePluginHolder']]],
   ['states_102',['states',['../namespacegl.html#a1d1dfbaa95ddc71b55b20bca67a16d33',1,'gl']]],
   ['statestack_103',['stateStack',['../classLowLevelGraphicsPostScriptRenderer.html#a95a55fd1cd7588048a37ac86fa384849',1,'LowLevelGraphicsPostScriptRenderer']]],
@@ -120,11 +120,11 @@ var searchData=
   ['strides_117',['strides',['../namespacegl.html#ab3fb3e346bf30cc218822c55a0eb74c5',1,'gl']]],
   ['string_118',['string',['../classOSCTypes.html#ad427b15ae32b26b2e0c28f0932eed263',1,'OSCTypes::string()'],['../namespacegl.html#ad7acdf57d94829f964ff1dc581fc4705',1,'gl::string()']]],
   ['stringlen_119',['stringlen',['../namespacegl.html#acde29865e531b4849f88ed20c6dcf0a7',1,'gl']]],
-  ['stringrange_120',['stringRange',['../classTextLayout_1_1Line.html#a2980388305522b3a4595196e7bbf09a2',1,'TextLayout::Line::stringRange()'],['../classTextLayout_1_1Run.html#a5e78255b382519784f9950efeae14f57',1,'TextLayout::Run::stringRange()']]],
+  ['stringrange_120',['stringRange',['../classTextLayout_1_1Run.html#a5e78255b382519784f9950efeae14f57',1,'TextLayout::Run::stringRange()'],['../classTextLayout_1_1Line.html#a2980388305522b3a4595196e7bbf09a2',1,'TextLayout::Line::stringRange()']]],
   ['strings_121',['strings',['../namespacegl.html#a8639a2c90be16742b8efb795d7c7a4ed',1,'gl::strings()'],['../classStringArray.html#ac10f010a31e1dcd6220d278a1603e37a',1,'StringArray::strings()']]],
   ['strokepath_122',['strokePath',['../classDrawableShape.html#a9400e1628d38b4719c211da4158bc2ff',1,'DrawableShape']]],
   ['stroketype_123',['strokeType',['../classDrawableShape.html#af636e2ff4b818d2b51994291facb30f6',1,'DrawableShape']]],
-  ['style_124',['style',['../structPushNotifications_1_1Notification_1_1Action.html#a3ae288a9d4a6c29d907430ee38229166',1,'PushNotifications::Notification::Action::style()'],['../classComponentPeer.html#aa96d0558fabd66eea5baeded157a873d',1,'ComponentPeer::style()'],['../classTypeface.html#a4169174330e29936cda2170a51a36df8',1,'Typeface::style()']]],
+  ['style_124',['style',['../classTypeface.html#a4169174330e29936cda2170a51a36df8',1,'Typeface::style()'],['../classComponentPeer.html#aa96d0558fabd66eea5baeded157a873d',1,'ComponentPeer::style()'],['../structPushNotifications_1_1Notification_1_1Action.html#a3ae288a9d4a6c29d907430ee38229166',1,'PushNotifications::Notification::Action::style()']]],
   ['styleflags_125',['styleFlags',['../classComponentPeer.html#a8322b7cdb134bc52f443cd587ffc3f75',1,'ComponentPeer']]],
   ['subcategoryname_126',['subcategoryName',['../structUnitTestRunner_1_1TestResult.html#af0a632786980a63693a86bb9942959c0',1,'UnitTestRunner::TestResult']]],
   ['subfolders_127',['subFolders',['../structKnownPluginList_1_1PluginTree.html#a46a202981e3ec6943e51ddbe2866a8d0',1,'KnownPluginList::PluginTree']]],
